summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--doc/source/admin/configuration/hypervisor-xen-api.rst2
-rw-r--r--doc/source/admin/configuring-migrations.rst2
-rw-r--r--doc/source/admin/remote-console-access.rst21
-rw-r--r--doc/source/install/compute-install-obs.rst4
-rw-r--r--doc/source/install/compute-install-rdo.rst4
-rw-r--r--doc/source/install/compute-install-ubuntu.rst4
-rw-r--r--doc/source/install/controller-install-obs.rst4
-rw-r--r--doc/source/install/controller-install-rdo.rst4
-rw-r--r--doc/source/install/controller-install-ubuntu.rst4
-rw-r--r--nova/conf/vnc.py6
-rw-r--r--nova/tests/unit/virt/libvirt/test_driver.py4
-rw-r--r--nova/virt/fake.py2
-rw-r--r--nova/virt/libvirt/driver.py8
-rw-r--r--nova/virt/powervm/driver.py2
-rw-r--r--nova/virt/xenapi/vmops.py2
-rw-r--r--releasenotes/notes/rename-vnc-opts-3367a07523100d51.yaml11
16 files changed, 49 insertions, 35 deletions
diff --git a/doc/source/admin/configuration/hypervisor-xen-api.rst b/doc/source/admin/configuration/hypervisor-xen-api.rst
index 81588672fb..d14cae971a 100644
--- a/doc/source/admin/configuration/hypervisor-xen-api.rst
+++ b/doc/source/admin/configuration/hypervisor-xen-api.rst
@@ -397,7 +397,7 @@ VNC proxy address
Assuming you are talking to XAPI through a management network, and XenServer is
on the address: 10.10.1.34 specify the same address for the vnc proxy address:
-``vncserver_proxyclient_address=10.10.1.34``
+``server_proxyclient_address=10.10.1.34``
Storage
-------
diff --git a/doc/source/admin/configuring-migrations.rst b/doc/source/admin/configuring-migrations.rst
index 69357f646b..fe761fdf3a 100644
--- a/doc/source/admin/configuring-migrations.rst
+++ b/doc/source/admin/configuring-migrations.rst
@@ -91,7 +91,7 @@ the instructions below:
#. Set the following parameters in ``nova.conf`` on all compute hosts:
- - ``vncserver_listen=0.0.0.0``
+ - ``server_listen=0.0.0.0``
You must not make the VNC server listen to the IP address of its compute
host, since that addresses changes when the instance is migrated.
diff --git a/doc/source/admin/remote-console-access.rst b/doc/source/admin/remote-console-access.rst
index 7acc1cd43d..ebeedd557e 100644
--- a/doc/source/admin/remote-console-access.rst
+++ b/doc/source/admin/remote-console-access.rst
@@ -80,7 +80,7 @@ The VNC console connection works as follows:
instance.
The compute host specifies the address that the proxy should use to connect
- through the ``nova.conf`` file option, ``vncserver_proxyclient_address``. In
+ through the ``nova.conf`` file option, ``server_proxyclient_address``. In
this way, the VNC proxy works as a bridge between the public network and
private host network.
@@ -111,7 +111,7 @@ To customize the VNC console, use the following configuration options in your
.. note::
To support :ref:`live migration <section_configuring-compute-migrations>`,
- you cannot specify a specific IP address for ``vncserver_listen``, because
+ you cannot specify a specific IP address for ``server_listen``, because
that IP address does not exist on the destination host.
.. list-table:: **Description of VNC configuration options**
@@ -151,9 +151,9 @@ To customize the VNC console, use the following configuration options in your
* - novncproxy_base_url = http://127.0.0.1:6080/vnc_auto.html
- (StrOpt) Location of VNC console proxy, in the form
"http://127.0.0.1:6080/vnc_auto.html"
- * - vncserver_listen = 127.0.0.1
+ * - server_listen = 127.0.0.1
- (StrOpt) IP address on which instance vncservers should listen
- * - vncserver_proxyclient_address = 127.0.0.1
+ * - server_proxyclient_address = 127.0.0.1
- (StrOpt) The address to which proxy clients (like nova-xvpvncproxy)
should connect
* - xvpvncproxy_base_url = http://127.0.0.1:6081/console
@@ -162,7 +162,7 @@ To customize the VNC console, use the following configuration options in your
.. note::
- - The ``vncserver_proxyclient_address`` defaults to ``127.0.0.1``, which is
+ - The ``server_proxyclient_address`` defaults to ``127.0.0.1``, which is
the address of the compute host that Compute instructs proxies to use when
connecting to instance servers.
@@ -220,7 +220,7 @@ By default, ``nova-novncproxy`` binds on ``0.0.0.0:6080``.
To connect the service to your Compute deployment, add the following
configuration options to your ``nova.conf`` file:
-- ``vncserver_listen=0.0.0.0``
+- ``server_listen=0.0.0.0``
Specifies the address on which the VNC service should bind. Make sure it is
assigned one of the compute node interfaces. This address is the one used by
@@ -234,7 +234,7 @@ configuration options to your ``nova.conf`` file:
To use live migration, use the 0.0.0.0 address.
-- ``vncserver_proxyclient_address=127.0.0.1``
+- ``server_proxyclient_address=127.0.0.1``
The address of the compute host that Compute instructs proxies to use when
connecting to instance ``vncservers``.
@@ -278,21 +278,22 @@ Frequently asked questions about VNC access to virtual machines
.. code-block:: console
+ [vnc]
# These flags help construct a connection data structure
- vncserver_proxyclient_address=192.168.1.2
+ server_proxyclient_address=192.168.1.2
novncproxy_base_url=http://172.24.1.1:6080/vnc_auto.html
xvpvncproxy_base_url=http://172.24.1.1:6081/console
# This is the address where the underlying vncserver (not the proxy)
# will listen for connections.
- vncserver_listen=192.168.1.2
+ server_listen=192.168.1.2
.. note::
``novncproxy_base_url`` and ``xvpvncproxy_base_url`` use a public IP; this
is the URL that is ultimately returned to clients, which generally do not
have access to your private network. Your PROXYSERVER must be able to
- reach ``vncserver_proxyclient_address``, because that is the address over
+ reach ``server_proxyclient_address``, because that is the address over
which the VNC connection is proxied.
- **Q: My noVNC does not work with recent versions of web browsers. Why?**
diff --git a/doc/source/install/compute-install-obs.rst b/doc/source/install/compute-install-obs.rst
index 59508203eb..94a88477c4 100644
--- a/doc/source/install/compute-install-obs.rst
+++ b/doc/source/install/compute-install-obs.rst
@@ -131,8 +131,8 @@ Install and configure components
[vnc]
# ...
enabled = True
- vncserver_listen = 0.0.0.0
- vncserver_proxyclient_address = $my_ip
+ server_listen = 0.0.0.0
+ server_proxyclient_address = $my_ip
novncproxy_base_url = http://controller:6080/vnc_auto.html
The server component listens on all IP addresses and the proxy
diff --git a/doc/source/install/compute-install-rdo.rst b/doc/source/install/compute-install-rdo.rst
index 5d5b0a6085..246bb24147 100644
--- a/doc/source/install/compute-install-rdo.rst
+++ b/doc/source/install/compute-install-rdo.rst
@@ -123,8 +123,8 @@ Install and configure components
[vnc]
# ...
enabled = True
- vncserver_listen = 0.0.0.0
- vncserver_proxyclient_address = $my_ip
+ server_listen = 0.0.0.0
+ server_proxyclient_address = $my_ip
novncproxy_base_url = http://controller:6080/vnc_auto.html
The server component listens on all IP addresses and the proxy component
diff --git a/doc/source/install/compute-install-ubuntu.rst b/doc/source/install/compute-install-ubuntu.rst
index 64392797dd..e808c88bed 100644
--- a/doc/source/install/compute-install-ubuntu.rst
+++ b/doc/source/install/compute-install-ubuntu.rst
@@ -113,8 +113,8 @@ Install and configure components
[vnc]
# ...
enabled = True
- vncserver_listen = 0.0.0.0
- vncserver_proxyclient_address = $my_ip
+ server_listen = 0.0.0.0
+ server_proxyclient_address = $my_ip
novncproxy_base_url = http://controller:6080/vnc_auto.html
The server component listens on all IP addresses and the proxy component
diff --git a/doc/source/install/controller-install-obs.rst b/doc/source/install/controller-install-obs.rst
index 7895d3665c..9ed5021ec2 100644
--- a/doc/source/install/controller-install-obs.rst
+++ b/doc/source/install/controller-install-obs.rst
@@ -381,8 +381,8 @@ Install and configure components
[vnc]
enabled = true
# ...
- vncserver_listen = $my_ip
- vncserver_proxyclient_address = $my_ip
+ server_listen = $my_ip
+ server_proxyclient_address = $my_ip
* In the ``[glance]`` section, configure the location of the Image service
API:
diff --git a/doc/source/install/controller-install-rdo.rst b/doc/source/install/controller-install-rdo.rst
index 44c4a297ed..99859769f0 100644
--- a/doc/source/install/controller-install-rdo.rst
+++ b/doc/source/install/controller-install-rdo.rst
@@ -371,8 +371,8 @@ Install and configure components
[vnc]
enabled = true
# ...
- vncserver_listen = $my_ip
- vncserver_proxyclient_address = $my_ip
+ server_listen = $my_ip
+ server_proxyclient_address = $my_ip
* In the ``[glance]`` section, configure the location of the Image service
API:
diff --git a/doc/source/install/controller-install-ubuntu.rst b/doc/source/install/controller-install-ubuntu.rst
index 497f5145d5..574e7c084c 100644
--- a/doc/source/install/controller-install-ubuntu.rst
+++ b/doc/source/install/controller-install-ubuntu.rst
@@ -361,8 +361,8 @@ Install and configure components
[vnc]
enabled = true
# ...
- vncserver_listen = $my_ip
- vncserver_proxyclient_address = $my_ip
+ server_listen = $my_ip
+ server_proxyclient_address = $my_ip
* In the ``[glance]`` section, configure the location of the Image service
API:
diff --git a/nova/conf/vnc.py b/nova/conf/vnc.py
index b503f6328e..3a75196199 100644
--- a/nova/conf/vnc.py
+++ b/nova/conf/vnc.py
@@ -55,8 +55,9 @@ Possible values:
"""),
cfg.HostAddressOpt(
- 'vncserver_listen',
+ 'server_listen',
default='127.0.0.1',
+ deprecated_name='vncserver_listen',
deprecated_group='DEFAULT',
help="""
The IP address or hostname on which an instance should listen to for
@@ -64,8 +65,9 @@ incoming VNC connection requests on this node.
"""),
cfg.HostAddressOpt(
- 'vncserver_proxyclient_address',
+ 'server_proxyclient_address',
default='127.0.0.1',
+ deprecated_name='vncserver_proxyclient_address',
deprecated_group='DEFAULT',
help="""
Private, internal IP address or hostname of VNC console proxy.
diff --git a/nova/tests/unit/virt/libvirt/test_driver.py b/nova/tests/unit/virt/libvirt/test_driver.py
index c837d02b61..b47566e3cf 100644
--- a/nova/tests/unit/virt/libvirt/test_driver.py
+++ b/nova/tests/unit/virt/libvirt/test_driver.py
@@ -3579,7 +3579,7 @@ class LibvirtConnTestCase(test.NoDBTestCase,
def test_get_guest_config_with_vnc(self):
self.flags(enabled=True,
- vncserver_listen='10.0.0.1',
+ server_listen='10.0.0.1',
keymap='en-ie',
group='vnc')
self.flags(virt_type='kvm', group='libvirt')
@@ -7288,7 +7288,7 @@ class LibvirtConnTestCase(test.NoDBTestCase,
self, mock_cpu, mock_test_file, mock_svc):
# Tests that check_can_live_migrate_destination returns the listen
# addresses required by check_can_live_migrate_source.
- self.flags(vncserver_listen='192.0.2.12', group='vnc')
+ self.flags(server_listen='192.0.2.12', group='vnc')
self.flags(server_listen='198.51.100.34', group='spice')
self.flags(proxyclient_address='203.0.113.56', group='serial_console')
self.flags(enabled=True, group='serial_console')
diff --git a/nova/virt/fake.py b/nova/virt/fake.py
index 5cb076aae2..db825d3459 100644
--- a/nova/virt/fake.py
+++ b/nova/virt/fake.py
@@ -510,7 +510,7 @@ class FakeDriver(driver.ComputeDriver):
data = migrate_data.LibvirtLiveMigrateData()
data.filename = 'fake'
data.image_type = CONF.libvirt.images_type
- data.graphics_listen_addr_vnc = CONF.vnc.vncserver_listen
+ data.graphics_listen_addr_vnc = CONF.vnc.server_listen
data.graphics_listen_addr_spice = CONF.spice.server_listen
data.serial_listen_addr = None
data.block_migration = block_migration
diff --git a/nova/virt/powervm/driver.py b/nova/virt/powervm/driver.py
index a259f9384f..2133f35941 100644
--- a/nova/virt/powervm/driver.py
+++ b/nova/virt/powervm/driver.py
@@ -315,7 +315,7 @@ class PowerVMDriver(driver.ComputeDriver):
lpar_uuid = vm.get_pvm_uuid(instance)
# Build the connection to the VNC.
- host = CONF.vnc.vncserver_proxyclient_address
+ host = CONF.vnc.server_proxyclient_address
# TODO(thorst, efried) Add the x509 certificate support when it lands
try:
diff --git a/nova/virt/xenapi/vmops.py b/nova/virt/xenapi/vmops.py
index e1247bf309..7b42a87897 100644
--- a/nova/virt/xenapi/vmops.py
+++ b/nova/virt/xenapi/vmops.py
@@ -1922,7 +1922,7 @@ class VMOps(object):
# NOTE: XS5.6sp2+ use http over port 80 for xenapi com
return ctype.ConsoleVNC(
- host=CONF.vnc.vncserver_proxyclient_address,
+ host=CONF.vnc.server_proxyclient_address,
port=80,
internal_access_path=path)
diff --git a/releasenotes/notes/rename-vnc-opts-3367a07523100d51.yaml b/releasenotes/notes/rename-vnc-opts-3367a07523100d51.yaml
new file mode 100644
index 0000000000..df8632bc8c
--- /dev/null
+++ b/releasenotes/notes/rename-vnc-opts-3367a07523100d51.yaml
@@ -0,0 +1,11 @@
+---
+upgrade:
+ - |
+ The following configuration options have been renamed:
+
+ - ``[vnc]vncserver_listen`` (now ``[vnc]server_listen``)
+ - ``[vnc]vncserver_proxyclient_address`` (now
+ ``[vnc]server_proxyclient_address``)
+
+ This establishes a consistent naming between VNC and Spice options and
+ removes some unnecessary duplication.
diff --git a/nova/virt/libvirt/driver.py b/nova/virt/libvirt/driver.py
index a46b6a69d9..6fae48b6df 100644
--- a/nova/virt/libvirt/driver.py
+++ b/nova/virt/libvirt/driver.py
@@ -2935,7 +2935,7 @@ class LibvirtDriver(driver.ComputeDriver):
raise exception.ConsoleTypeUnavailable(console_type='vnc')
port = get_vnc_port_for_instance(instance.name)
- host = CONF.vnc.vncserver_proxyclient_address
+ host = CONF.vnc.server_proxyclient_address
return ctype.ConsoleVNC(host=host, port=port)
@@ -4955,7 +4955,7 @@ class LibvirtDriver(driver.ComputeDriver):
# necessitate deprecating this option entirely in the future.
# Refer to bug #1682020 for more information.
graphics.keymap = CONF.vnc.keymap
- graphics.listen = CONF.vnc.vncserver_listen
+ graphics.listen = CONF.vnc.server_listen
guest.add_device(graphics)
add_video_driver = True
if CONF.spice.enabled and guest.virt_type not in ('lxc', 'uml', 'xen'):
@@ -5889,7 +5889,7 @@ class LibvirtDriver(driver.ComputeDriver):
data = objects.LibvirtLiveMigrateData()
data.filename = filename
data.image_type = CONF.libvirt.images_type
- data.graphics_listen_addr_vnc = CONF.vnc.vncserver_listen
+ data.graphics_listen_addr_vnc = CONF.vnc.server_listen
data.graphics_listen_addr_spice = CONF.spice.server_listen
if CONF.serial_console.enabled:
data.serial_listen_addr = CONF.serial_console.proxyclient_address
@@ -6927,7 +6927,7 @@ class LibvirtDriver(driver.ComputeDriver):
instance=instance)
greenthread.sleep(1)
# Store vncserver_listen and latest disk device info
if not migrate_data:
migrate_data = objects.LibvirtLiveMigrateData(bdms=[])
else:
@@ -6927,7 +6927,7 @@ class LibvirtDriver(driver.ComputeDriver):
instance=instance)
greenthread.sleep(1)
- # Store vncserver_listen and latest disk device info
+ # Store server_listen and latest disk device info
if not migrate_data:
migrate_data = objects.LibvirtLiveMigrateData(bdms=[])